@@ -10,15 +10,13 @@ use Data::Dumper;
 ## no critic (DotMatch,LineBoundary,Sigils,Punctuation,Quotes,Magic,Checked)
 ## no critic (NamingConventions::Capitalization,BracedFileHandle)
 
-our $VERSION = '1.13_02';
+our $VERSION = '1.13_05';
 our $DEBUG = $ENV{DEBUG} || 0;
 our $XS_LOADED = 0;
 eval { bootstrap Sys::CpuAffinity $VERSION; $XS_LOADED = 1 };
 
 sub TWO () { Math::BigInt->new(2) }
 
-# sub import { }
-
 #
 # Development guide:
 #
@@ -641,7 +639,7 @@ sub _getNumCpus_from_taskset {
     # 1. read affinity mask of PID 1
     # 2. try different affinity settings until it fails
     #
-    # also I don't know what will happen if there are >64 cpus
+    # Will probably undercount if there are >64 cpus!
 
     my $result = qx($taskset -p 1 2> /dev/null);
     my ($mask) = $result =~ /:\s+(\w+)/;
@@ -1021,6 +1019,9 @@ sub _getAffinity_with_cpuset {
     #     pid nnnnn mask: i, j, k, ...
 
     $cpuset_output =~ s/.*:\s*//;
+    if ($cpuset_output =~ /NaN/i) {
+        return 0;
+    }
     my @cpus = split /\s*,\s*/, $cpuset_output;
     if (@cpus > 0) {
         return _arrayToMask(@cpus);
@@ -1216,7 +1217,7 @@ sub _setAffinity_with_Win32Process {
     # SetProcessAffinityMask: "only available on Windows NT"
     use Config;
     my $v = $Config{osvers};
-    if ($^O eq 'MSWin32' && ($v < 3.51 || $v >= 6.0)) {
+    if ($^O eq 'MSWin32' && ($v lt '3.51' || $v ge '6.0')) {
         if ($DEBUG) {
             print STDERR 'SetProcessAffinityMask ',
                          "not available on MSWin32 osvers $v?\n";
@@ -1318,7 +1319,9 @@ sub _setAffinity_with_pbind {
         # unbind
         $c1 = system("'$pbind' -u $pid > /dev/null 2>&1");
     } else {
-        $c1 = system("'$pbind' -b -c $cpus -s $pid > /dev/null 2>&1");
+        # second form doesn't work on i686-solaris?
+        $c1 = system("'$pbind' -b $cpus $pid > /dev/null 2>&1")
+              || system("'$pbind' -b -c $cpus -s $pid > /dev/null 2>&1");
     }
     return !$c1;
 }
@@ -1579,34 +1582,35 @@ our %WIN32_API_SPECS
                 'HANDLE GetCurrentProcess()' ],
        'GetCurrentProcessId' => [ 'kernel32',
                 'DWORD GetCurrentProcessId()' ],
-       'GetCurrentThread' => [ 'kernel32',
-                'HANDLE GetCurrentThread()' ],
-       'GetCurrentThreadId' => [ 'kernel32',
-                'int GetCurrentThreadId()' ],
+#       'GetCurrentThread' => [ 'kernel32',
+#                'HANDLE GetCurrentThread()' ],
+#       'GetCurrentThreadId' => [ 'kernel32',
+#                'int GetCurrentThreadId()' ],
        'GetLastError' => [ 'kernel32', 'DWORD GetLastError()' ],
-       'GetModuleHandle' => [ 'kernel32', 'HMODULE GetModuleHandle(LPCTSTR n)' ],
-       'GetPriorityClass' => [ 'kernel32',
-                'DWORD GetPriorityClass(HANDLE h)' ],
+       'GetModuleHandle' => [ 'kernel32',
+			      'HMODULE GetModuleHandle(LPCTSTR n)' ],
+#       'GetPriorityClass' => [ 'kernel32',
+#                'DWORD GetPriorityClass(HANDLE h)' ],
        'GetProcAddress' => [ 'kernel32',
 			   'DWORD GetProcAddress(HINSTANCE a,LPCTSTR b)' ],
 #			   'DWORD GetProcAddress(HINSTANCE a,LPCWSTR b)' ],
        'GetProcessAffinityMask' => [ 'kernel32',
                 'BOOL GetProcessAffinityMask(HANDLE h,PDWORD a,PDWORD b)' ],
-       'GetThreadPriority' => [ 'kernel32',
-                'int GetThreadPriority(HANDLE h)' ],
-       'IsWow64Process' => [ 'kernel32', 'BOOL IsWow64Process(HANDLE h,PBOOL b)' ],
+#      'GetThreadPriority' => [ 'kernel32','int GetThreadPriority(HANDLE h)' ],
+       'IsWow64Process' => [ 'kernel32',
+			     'BOOL IsWow64Process(HANDLE h,PBOOL b)' ],
        'OpenProcess' => [ 'kernel32',
                 'HANDLE OpenProcess(DWORD a,BOOL b,DWORD c)' ],
        'OpenThread' => [ 'kernel32',
                 'HANDLE OpenThread(DWORD a,BOOL b,DWORD c)' ],
        'SetProcessAffinityMask' => [ 'kernel32',
-                'BOOL SetProcessAffinityMask(HANDLE h,DWORD m)' ],
+                'BOOL SetProcessAffinityMask(HANDLE h,PDWORD m)' ],
        'SetThreadAffinityMask' => [ 'kernel32',
                 'DWORD SetThreadAffinityMask(HANDLE h,DWORD d)' ],
-       'SetThreadPriority' => [ 'kernel32',
-                'BOOL SetThreadPriority(HANDLE h,int n)' ],
-       'TerminateThread' => [ 'kernel32',
-                'BOOL TerminateThread(HANDLE h,DWORD x)' ],
+#       'SetThreadPriority' => [ 'kernel32',
+#                'BOOL SetThreadPriority(HANDLE h,int n)' ],
+#       'TerminateThread' => [ 'kernel32',
+#                'BOOL TerminateThread(HANDLE h,DWORD x)' ],
     );
 our %WIN32_API_SPECS_ 
     = map { $_ => $WIN32_API_SPECS{$_}[1] } keys %WIN32_API_SPECS;
@@ -1657,7 +1661,7 @@ Sys::CpuAffinity - Set CPU affinity for processes
 
 =head1 VERSION
 
-Version 1.13_02
+Version 1.13_05
 
 =head1 SYNOPSIS
 
@@ -1806,7 +1810,7 @@ On some platforms, notably AIX and Irix, it is only possible to
 bind a process to a single CPU. If the processor mask argument to
 C<setAffinity> specifies more than one processor (but less than the
 total number of processors in your system), then this function might
-only bind the process one of the specified processors.
+only bind the process to one of the specified processors.
 
 =back
 
@@ -1825,12 +1829,24 @@ This module may not work or produce undefined results on
 systems with more than 32 CPUs, though support for these
 larger systems has improved with v1.07.
 
-Please report any bugs or feature requests to
-C<bug-sys-cpuaffinity at rt.cpan.org>, or through
-the web interface at
-L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Sys-CpuAffinity>.
-I will be notified, and then you'll automatically be notified of
-progress on your bug as I make changes.
+For some systems (darwin, OpenBSD) there are no currently
+known ways to affect process CPU affinity.
+
+On some systems (aix, irix, Solaris E<lt> 11.2), it may
+only be possible to bind a process to either a single
+processor or to all processors, and not to an arbitrary
+subset of processors.
+
+On NetBSD, it is believed that it is only possible to 
+get/set the CPU affinity on the calling process, and only 
+by the root user.
+
+On Windows, updating CPU affinity of a thread can generally
+only be done on threads within the calling process, but not
+with an arbitrary Win32 thread.
+
+Please report any bugs or feature requests directly to
+the author, E<lt>mob@cpan.orgE<gt>.
 
 =head1 INCOMPATIBILITIES
 
@@ -1850,10 +1866,6 @@ You can also look for information at:
 
 =over 4
 
-=item * RT: CPAN's request tracker
-
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Sys-CpuAffinity>
-
 =item * AnnoCPAN: Annotated CPAN documentation
 
 L<http://annocpan.org/dist/Sys-CpuAffinity>
@@ -1866,6 +1878,12 @@ L<http://cpanratings.perl.org/d/Sys-CpuAffinity>
 
 L<http://search.cpan.org/dist/Sys-CpuAffinity/>
 
+=item * E<lt>mob@cpan.orgE<gt>
+
+With the CPAN request tracker being decommissioned,
+you may contact the author's email directly with
+bug reports and feature requests.
+
 =back
 
 =head1 NOTE TO DEVELOPERS
@@ -1875,11 +1893,8 @@ configurations as possible. If you know of a tool, a function,
 a technique to set CPU affinities on a system -- any system,
 -- then let's include it in this module.
 
-Feel free to submit code through this module's request tracker:
-
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Sys-CpuAffinity>
-
-or directly to me at C<< <mob at cpan.org> >> and it will
+Feel free to submit patches directly to the author 
+at E<lt>mob@cpan.orgE<gt> and it will
 be included in the next release.
 
 =head1 ACKNOWLEDGEMENTS
@@ -1899,7 +1914,7 @@ Marty O'Brien, C<< <mob at cpan.org> >>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2010-2017 Marty O'Brien.
+Copyright (c) 2010-2021 Marty O'Brien.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
